Coverage for testrail_api_reporter/__init__.py: 100%

1# -*- coding: utf-8 -*-

2""" testrail_api_reporter package """

3

4# Engines

5 from .engines.at_coverage_reporter import ATCoverageReporter

6 from .engines.plotly_reporter import PlotlyReporter

7 from .engines.results_reporter import TestRailResultsReporter

8

9# Publishers

10 from .publishers.confluence_sender import ConfluenceSender

11 from .publishers.email_sender import EmailSender

12 from .publishers.slack_sender import SlackSender

13 from .publishers.gdrive_uploader import GoogleDriveUploader

14

15# Utils

16 from .utils.reporter_utils import upload_image, delete_file, zip_file

17 from .utils.logger_config import setup_logger